[Python-checkins] bpo-44732: Rename types.Union to types.UnionType (GH-27342)

miss-islington webhook-mailer at python.org
Mon Jul 26 15:03:08 EDT 2021


https://github.com/python/cpython/commit/8a37e8cf45105fbb592c31ebd30501bbdea5ab81
commit: 8a37e8cf45105fbb592c31ebd30501bbdea5ab81
branch: 3.10
author: Miss Islington (bot) <31488909+miss-islington at users.noreply.github.com>
committer: miss-islington <31488909+miss-islington at users.noreply.github.com>
date: 2021-07-26T12:02:58-07:00
summary:

bpo-44732: Rename types.Union to types.UnionType (GH-27342)


Co-authored-by: Łukasz Langa <lukasz at langa.pl>
Co-authored-by: Jelle Zijlstra <jelle.zijlstra at gmail.com>
(cherry picked from commit 2b8ad9e6c5f0a66e9ca2d15f85336d8a3eefefb0)

Co-authored-by: Hasan <hasan.aleeyev at gmail.com>

files:
A Misc/NEWS.d/next/Core and Builtins/2021-07-26-15-27-03.bpo-44732.IxObt3.rst
M Doc/library/stdtypes.rst
M Doc/library/types.rst
M Lib/test/test_typing.py
M Lib/types.py
M Lib/typing.py
M Objects/unionobject.c

diff --git a/Doc/library/stdtypes.rst b/Doc/library/stdtypes.rst
index 3b2ff8090ced3..87a343dbe422c 100644
--- a/Doc/library/stdtypes.rst
+++ b/Doc/library/stdtypes.rst
@@ -5040,16 +5040,16 @@ enables cleaner type hinting syntax compared to :data:`typing.Union`.
       TypeError: isinstance() argument 2 cannot contain a parameterized generic
 
 The user-exposed type for the union object can be accessed from
-:data:`types.Union` and used for :func:`isinstance` checks.  An object cannot be
+:data:`types.UnionType` and used for :func:`isinstance` checks.  An object cannot be
 instantiated from the type::
 
    >>> import types
-   >>> isinstance(int | str, types.Union)
+   >>> isinstance(int | str, types.UnionType)
    True
-   >>> types.Union()
+   >>> types.UnionType()
    Traceback (most recent call last):
      File "<stdin>", line 1, in <module>
-   TypeError: cannot create 'types.Union' instances
+   TypeError: cannot create 'types.UnionType' instances
 
 .. note::
    The :meth:`__or__` method for type objects was added to support the syntax
diff --git a/Doc/library/types.rst b/Doc/library/types.rst
index 2dfc0f2fcadf3..88fe47a8d4a7f 100644
--- a/Doc/library/types.rst
+++ b/Doc/library/types.rst
@@ -312,7 +312,7 @@ Standard names are defined for the following types:
       This type can now be subclassed.
 
 
-.. data:: Union
+.. data:: UnionType
 
    The type of :ref:`union type expressions<types-union>`.
 
diff --git a/Lib/test/test_typing.py b/Lib/test/test_typing.py
index 8cbbe622d5a49..f79675b4bdf9b 100644
--- a/Lib/test/test_typing.py
+++ b/Lib/test/test_typing.py
@@ -3084,7 +3084,7 @@ class C(Generic[T]): pass
         self.assertIs(get_origin(Callable), collections.abc.Callable)
         self.assertIs(get_origin(list[int]), list)
         self.assertIs(get_origin(list), None)
-        self.assertIs(get_origin(list | str), types.Union)
+        self.assertIs(get_origin(list | str), types.UnionType)
         self.assertIs(get_origin(P.args), P)
         self.assertIs(get_origin(P.kwargs), P)
 
diff --git a/Lib/types.py b/Lib/types.py
index c509b242d5d8f..c2dc97dd57ae3 100644
--- a/Lib/types.py
+++ b/Lib/types.py
@@ -297,9 +297,8 @@ def wrapped(*args, **kwargs):
 
     return wrapped
 
-
 GenericAlias = type(list[int])
-Union = type(int | str)
+UnionType = type(int | str)
 
 EllipsisType = type(Ellipsis)
 NoneType = type(None)
diff --git a/Lib/typing.py b/Lib/typing.py
index ae31589dc4339..2c2d8ec1a1e96 100644
--- a/Lib/typing.py
+++ b/Lib/typing.py
@@ -167,7 +167,7 @@ def _type_check(arg, msg, is_argument=True, module=None):
         return arg
     if isinstance(arg, _SpecialForm) or arg in (Generic, Protocol):
         raise TypeError(f"Plain {arg} is not valid as type argument")
-    if isinstance(arg, (type, TypeVar, ForwardRef, types.Union, ParamSpec)):
+    if isinstance(arg, (type, TypeVar, ForwardRef, types.UnionType, ParamSpec)):
         return arg
     if not callable(arg):
         raise TypeError(f"{msg} Got {arg!r:.100}.")
@@ -207,7 +207,7 @@ def _collect_type_vars(types_, typevar_types=None):
     for t in types_:
         if isinstance(t, typevar_types) and t not in tvars:
             tvars.append(t)
-        if isinstance(t, (_GenericAlias, GenericAlias, types.Union)):
+        if isinstance(t, (_GenericAlias, GenericAlias, types.UnionType)):
             tvars.extend([t for t in t.__parameters__ if t not in tvars])
     return tuple(tvars)
 
@@ -260,7 +260,7 @@ def _remove_dups_flatten(parameters):
     # Flatten out Union[Union[...], ...].
     params = []
     for p in parameters:
-        if isinstance(p, (_UnionGenericAlias, types.Union)):
+        if isinstance(p, (_UnionGenericAlias, types.UnionType)):
             params.extend(p.__args__)
         elif isinstance(p, tuple) and len(p) > 0 and p[0] is Union:
             params.extend(p[1:])
@@ -314,13 +314,13 @@ def _eval_type(t, globalns, localns, recursive_guard=frozenset()):
     """
     if isinstance(t, ForwardRef):
         return t._evaluate(globalns, localns, recursive_guard)
-    if isinstance(t, (_GenericAlias, GenericAlias, types.Union)):
+    if isinstance(t, (_GenericAlias, GenericAlias, types.UnionType)):
         ev_args = tuple(_eval_type(a, globalns, localns, recursive_guard) for a in t.__args__)
         if ev_args == t.__args__:
             return t
         if isinstance(t, GenericAlias):
             return GenericAlias(t.__origin__, ev_args)
-        if isinstance(t, types.Union):
+        if isinstance(t, types.UnionType):
             return functools.reduce(operator.or_, ev_args)
         else:
             return t.copy_with(ev_args)
@@ -1030,7 +1030,7 @@ def __getitem__(self, params):
         for arg in self.__args__:
             if isinstance(arg, self._typevar_types):
                 arg = subst[arg]
-            elif isinstance(arg, (_GenericAlias, GenericAlias, types.Union)):
+            elif isinstance(arg, (_GenericAlias, GenericAlias, types.UnionType)):
                 subparams = arg.__parameters__
                 if subparams:
                     subargs = tuple(subst[x] for x in subparams)
@@ -1198,7 +1198,7 @@ def copy_with(self, params):
         return Union[params]
 
     def __eq__(self, other):
-        if not isinstance(other, (_UnionGenericAlias, types.Union)):
+        if not isinstance(other, (_UnionGenericAlias, types.UnionType)):
             return NotImplemented
         return set(self.__args__) == set(other.__args__)
 
@@ -1802,7 +1802,7 @@ def _strip_annotations(t):
         if stripped_args == t.__args__:
             return t
         return GenericAlias(t.__origin__, stripped_args)
-    if isinstance(t, types.Union):
+    if isinstance(t, types.UnionType):
         stripped_args = tuple(_strip_annotations(a) for a in t.__args__)
         if stripped_args == t.__args__:
             return t
@@ -1833,8 +1833,8 @@ def get_origin(tp):
         return tp.__origin__
     if tp is Generic:
         return Generic
-    if isinstance(tp, types.Union):
-        return types.Union
+    if isinstance(tp, types.UnionType):
+        return types.UnionType
     return None
 
 
@@ -1858,7 +1858,7 @@ def get_args(tp):
                          or isinstance(res[0], (ParamSpec, _ConcatenateGenericAlias)))):
             res = (list(res[:-1]), res[-1])
         return res
-    if isinstance(tp, types.Union):
+    if isinstance(tp, types.UnionType):
         return tp.__args__
     return ()
 
diff --git a/Misc/NEWS.d/next/Core and Builtins/2021-07-26-15-27-03.bpo-44732.IxObt3.rst b/Misc/NEWS.d/next/Core and Builtins/2021-07-26-15-27-03.bpo-44732.IxObt3.rst
new file mode 100644
index 0000000000000..5094688a29431
--- /dev/null
+++ b/Misc/NEWS.d/next/Core and Builtins/2021-07-26-15-27-03.bpo-44732.IxObt3.rst	
@@ -0,0 +1 @@
+Rename ``types.Union`` to ``types.UnionType``.
diff --git a/Objects/unionobject.c b/Objects/unionobject.c
index 475311e598d7b..9e670b47b7e63 100644
--- a/Objects/unionobject.c
+++ b/Objects/unionobject.c
@@ -1,4 +1,4 @@
 // types.Union -- used to represent e.g. Union[int, str], int | str
 #include "Python.h"
 #include "pycore_object.h"  // _PyObject_GC_TRACK/UNTRACK
 #include "pycore_unionobject.h"
@@ -414,7 +414,7 @@ union_parameters(PyObject *self, void *Py_UNUSED(unused))
 }
 
 static PyGetSetDef union_properties[] = {
-    {"__parameters__", union_parameters, (setter)NULL, "Type variables in the types.Union.", NULL},
+    {"__parameters__", union_parameters, (setter)NULL, "Type variables in the types.UnionType.", NULL},
     {0}
 };
 
@@ -424,7 +424,7 @@ static PyNumberMethods union_as_number = {
 
 PyTypeObject _PyUnion_Type = {
     PyVarObject_HEAD_INIT(&PyType_Type, 0)
-    .tp_name = "types.Union",
+    .tp_name = "types.UnionType",
     .tp_doc = "Represent a PEP 604 union type\n"
               "\n"
               "E.g. for int | str",
@@ -1,4 +1,4 @@
-// types.Union -- used to represent e.g. Union[int, str], int | str
+// types.UnionType -- used to represent e.g. Union[int, str], int | str
 #include "Python.h"
 #include "pycore_object.h"  // _PyObject_GC_TRACK/UNTRACK



More information about the Python-checkins mailing list